@@ -1,3 +1,24 @@
+/*
+ * Copyright (c) 2014  Roy Keene
+ *
+ * Permission is hereby granted, free of charge, to any person obtaining a copy
+ * of this software and associated documentation files (the "Software"), to deal
+ * in the Software without restriction, including without limitation the rights
+ * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+ * copies of the Software, and to permit persons to whom the Software is
+ * furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
+ */
 #define FUSE_USE_VERSION 26
 
 #include <sys/fsuid.h>
@@ -1984,13 +2005,19 @@ static int appfs_opt_parse(int argc, char **argv,  struct fuse_args *args) {
 					}
 
 					if (strcmp(optstr, "nothreads") == 0) {
+						APPFS_DEBUG("Passing option to FUSE: -s");
+
 						fuse_opt_parse(args, NULL, NULL, NULL);
 						fuse_opt_add_arg(args, "-s");
 
 						appfs_threaded_tcl = 0;
 					} else if (strcmp(optstr, "allow_other") == 0) {
+						APPFS_DEBUG("Passing option to FUSE: -o allow_Other");
+
 						fuse_opt_parse(args, NULL, NULL, NULL);
 						fuse_opt_add_arg(args, "-oallow_other");
+					} else if (strcmp(optstr, "rw") == 0) {
+						/* Ignored */
 					} else {
 						fprintf(stderr, "appfsd: invalid option: \"-o %s\"\n", optstr);
 
