@@ -1,5 +1,27 @@
 #! /usr/bin/env tclsh
 
+#
+# Copyright (c) 2014  Roy Keene
+#
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to deal
+# in the Software without restriction, including without limitation the rights
+# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
+#
+# The above copyright notice and this permission notice shall be included in
+# all copies or substantial portions of the Software.
+#
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+# THE SOFTWARE.
+#
+
 package require http 2.7
 package require sqlite3
 package require sha1
@@ -25,6 +47,7 @@ namespace eval ::appfs {
 	variable ttl 3600
 	variable nttl 60
 	variable trusted_cas [list]
+	variable platform [::platform::generic]
 
 	proc _hash_sep {hash {seps 4}} {
 		for {set idx 0} {$idx < $seps} {incr idx} {
@@ -121,7 +144,7 @@ namespace eval ::appfs {
 		return true
 	}
 
-	proc _normalizeOS {os} {
+	proc _normalizeOS {os {tolerant 0}} {
 		set os [string tolower [string trim $os]]
 
 		switch -- $os {
@@ -136,10 +159,14 @@ namespace eval ::appfs {
 			}
 		}
 
+		if {$tolerant} {
+			return $os
+		}
+
 		return -code error "Unable to normalize OS: $os"
 	}
 
-	proc _normalizeCPU {cpu} {
+	proc _normalizeCPU {cpu {tolerant 0}} {
 		set cpu [string tolower [string trim $cpu]]
 
 		switch -glob -- $cpu {
@@ -154,6 +181,10 @@ namespace eval ::appfs {
 			}
 		}
 
+		if {$tolerant} {
+			return $cpu
+		}
+
 		return -code error "Unable to normalize CPU: $cpu"
 	}
 
@@ -506,8 +537,8 @@ E5AnJIlOnd/tGe0Chf0sFQg+l9nNiNrWGgzdd9ZPJK4=
 						set os_cpu [lindex $path 2]
 						set os_cpu [split $os_cpu "-"]
 
-						set retval(os) [lindex $os_cpu 0]
-						set retval(cpu) [lindex $os_cpu 1]
+						set retval(os) [_normalizeOS [lindex $os_cpu 0] 1]
+						set retval(cpu) [_normalizeCPU [lindex $os_cpu 1] 1]
 						set retval(_children) versions
 						set retval(_type) os-cpu
 
@@ -652,8 +683,17 @@ E5AnJIlOnd/tGe0Chf0sFQg+l9nNiNrWGgzdd9ZPJK4=
 			}
 			"os-cpu" {
 				if {$pathinfo(os) == "platform" && $pathinfo(cpu) == ""} {
+					set check [::appfs::db eval {
+						SELECT DISTINCT os, cpuArch FROM packages WHERE hostname = $pathinfo(hostname) AND package = $pathinfo(package);
+					}]
+
 					set retval(type) symlink
-					set retval(source) [platform::generic]
+
+					if {$check == [list "noarch" "noarch"]} {
+						set retval(source) "noarch-noarch"
+					} else {
+						set retval(source) $::appfs::platform
+					}
 				} else {
 					set check [::appfs::db onecolumn {
 						SELECT 1 FROM packages WHERE hostname = $pathinfo(hostname) AND package = $pathinfo(package) AND os = $pathinfo(os) AND cpuArch = $pathinfo(cpu);
